@@ -26,6 +26,7 @@
 #include <ktexteditor/application.h>
 #include <KTextEditor/Command>
 #include <ktexteditor/sessionconfiginterface.h>
+#include <KTextEditor/Message>
 #include <QAction>
 
 #include <QTreeWidget>
@@ -173,7 +174,6 @@ protected:
 private:
     QTreeWidgetItem *rootFileItem(const QString &url, const QString &fName);
     QStringList filterFiles(const QStringList& files) const;
-    QString currentWord(const KTextEditor::Document& document, const KTextEditor::Cursor& cursor) const;
 
     Ui::SearchDialog                   m_ui;
     QWidget                           *m_toolView;
@@ -192,6 +192,7 @@ private:
     QString                            m_resultBaseDir;
     QList<KTextEditor::MovingRange*>   m_matchRanges;
     QTimer                             m_changeTimer;
+    QPointer<KTextEditor::Message>     m_infoMessage;
 
     /**
      * current project plugin view, if any
